@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 
@@ -152,6 +152,9 @@ class GridDataMetrics(GdalAlgorithm):
     def groupId(self):
         return 'rasteranalysis'
 
+    def commandName(self):
+        return 'gdal_grid'
+
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
         ogrLayer, layerName = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
 
@@ -186,4 +189,4 @@ class GridDataMetrics(GdalAlgorithm):
         arguments.append(ogrLayer)
         arguments.append(out)
 
-        return ['gdal_grid', GdalUtils.escapeAndJoin(arguments)]
+        return [self.commandName(), GdalUtils.escapeAndJoin(arguments)]
