@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 
@@ -183,7 +183,7 @@ class BatchInputSelectionPanel(QWidget):
         self.valueChanged.emit()
 
     def value(self):
-        return self._value
+        return self._value if self._value else None
 
     def setValue(self, value):
         self._value = value
